summaryrefslogtreecommitdiff
path: root/macros/audio_macros.asm
diff options
context:
space:
mode:
authordannye <33dannye@gmail.com>2019-09-03 22:36:02 -0500
committerdannye <33dannye@gmail.com>2019-09-03 22:36:02 -0500
commit362bba7642431d87371cb86c9442e7636fcd287b (patch)
treedcbccdf05a241727033b66816f31bd2007258063 /macros/audio_macros.asm
parent44b9a240d4b2dd28737fa7aff37fb7d0582b25d6 (diff)
Rename dnote to drum_note and dspeed to drum_speed
Diffstat (limited to 'macros/audio_macros.asm')
-rwxr-xr-xmacros/audio_macros.asm8
1 files changed, 4 insertions, 4 deletions
diff --git a/macros/audio_macros.asm b/macros/audio_macros.asm
index 643114da..95b9ecbc 100755
--- a/macros/audio_macros.asm
+++ b/macros/audio_macros.asm
@@ -92,16 +92,16 @@ note: MACRO
ENDM
; arguments: instrument [1, 19], length [1, 16]
-dnote: MACRO
+drum_note: MACRO
db $B0 | (\2 - 1)
db \1
ENDM
; arguments: instrument, length [1, 16]
; like dnote but one 1 byte instead of 2
; can only be used with instruments 1-10, excluding 2
; unused
-dnote_short: MACRO
+drum_note_short: MACRO
db (\1 << 4) | (\2 - 1)
ENDM
@@ -124,7 +124,7 @@ note_type: MACRO
ENDM
; arguments: speed [0, 15]
-dspeed: MACRO
+drum_speed: MACRO
db $D0 | \1
ENDM
@@ -92,16 +92,16 @@ note: MACRO
ENDM
; arguments: instrument, length [1, 16]
-; like dnote but one 1 byte instead of 2
+; like drum_note but one 1 byte instead of 2
; can only be used with instruments 1-10, excluding 2
; unused